@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.11 1999/09/13 17:14:08 jsm Exp $	*/
+/*	$NetBSD: machdep.c,v 1.12 2003/08/07 09:37:38 agc Exp $	*/
 
 /*
  * Copyright (c) 1988, 1993
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -41,7 +37,7 @@
 #if 0
 static char sccsid[] = "@(#)machdep.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: machdep.c,v 1.11 1999/09/13 17:14:08 jsm Exp $");
+__RCSID("$NetBSD: machdep.c,v 1.12 2003/08/07 09:37:38 agc Exp $");
 #endif
 #endif /* not lint */
 
